@@ -30,7 +30,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdPath.c,v 1.10.6.1 2006/02/06 21:52:33 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdPath.c,v 1.10.6.1.10.1 2007/02/14 05:38:21 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -84,7 +84,7 @@ static char buffer[ PATH_BUFLEN];
 /** ************************************************************************ **/
 
 static int	Remove_Path( Tcl_Interp	*interp, char *variable, char *item, 
-			char *sw_marker);
+			char *sw_marker, const char *delim);
 
 
 /*++++
@@ -97,6 +97,7 @@ static int	Remove_Path( Tcl_Interp	*interp, char *variable, char *item,
  **			is to be appended or prepended.  Each directory in   **
  **			the path is checked to see whether it is already     **
  **			in the path.  If so it is not added.		     **
+ **			(Handles options -d C, or --delim[=]C )		     **
  ** 									     **
  **   First Edition:	1991/10/23					     **
  ** 									     **
@@ -122,17 +123,19 @@ int	cmdSetPath(	ClientData	 client_data,
 {
     Tcl_RegExp	chkexpPtr;			/** Regular expression for   **/
 						/** marker checking	     **/
-    char	*oldpath,			/** Old value of 'var'	     **/
-		*newpath,			/** New value of 'var'	     **/
-		*sw_marker = APP_SW_MARKER,	/** arbitrary default	     **/
-		*startp=NULL, *endp=NULL,	/** regexp match endpts	     **/
-		*qualifiedpath,			/** List of dirs which 
+    char	 *oldpath,			/** Old value of 'var'	     **/
+		 *newpath,			/** New value of 'var'	     **/
+		 *sw_marker = APP_SW_MARKER,	/** arbitrary default	     **/
+		 *startp=NULL, *endp=NULL,	/** regexp match endpts	     **/
+		 *qualifiedpath,		/** List of dirs which 
 						    aren't already in path   **/
 		**pathlist;			/** List of dirs	     **/
-    int		 append = 1,			/** append or prepend	     **/
-		 numpaths,			/** number of dirs in path   **/
-		 qpathlen,			/** qualifiedpath length     **/
-		 x;				/** loop index		     **/
+    const char	 *delim = _colon;		/** path delimiter	     **/
+    int		  append = 1,			/** append or prepend	     **/
+		  numpaths,			/** number of dirs in path   **/
+		  qpathlen,			/** qualifiedpath length     **/
+		  arg1 = 1,			/** arg start		     **/
+		  x;				/** loop index		     **/
 
 #if WITH_DEBUGGING_CALLBACK
     ErrorLogger( NO_ERR_START, LOC, _proc_cmdSetPath, NULL);
@@ -145,14 +148,15 @@ int	cmdSetPath(	ClientData	 client_data,
         goto success0;
 	
     /**
-     **   Check arguments. There should be give 3 args:
+     **   Check arguments. There should be at least 3 args:
      **     argv[0]  -  prepend/append
-     **     argv[1]  -  varname
-     **     argv[2]  -  value
+     **     ...
+     **     argv[n-1]-  varname
+     **     argv[n]  -  value
      **/
-    if(argc != 3)
-	if( OK != ErrorLogger(ERR_USAGE, LOC, argv[0],"path-variable directory",
-	    NULL))
+    if(argc < 3)
+	if( OK != ErrorLogger(ERR_USAGE, LOC, argv[0],
+	    " path-variable directory", NULL))
 	    goto unwind0;
 
     /**
@@ -185,31 +189,49 @@ int	cmdSetPath(	ClientData	 client_data,
 	fprintf( stderr, "\n");
         goto success0;
     }
-  
+
+    /**
+     **  Check for the delimiter option
+     **/
+    if(*(argv[arg1]) == '-') {
+	if (!strcmp(argv[arg1], "-d")) {
+		delim = argv[arg1+1];
+		arg1 += 2;
+	} else if (!strcmp(argv[arg1], "--delim")) {
+		delim = argv[arg1+1];
+		arg1 += 2;
+	} else if (!strncmp(argv[arg1], "--delim=", 8)) {
+		delim = argv[arg1]+8;
+		arg1++;
+	}
+    }
+
     /**
      **  Get the old value of the variable. MANPATH defaults to "/usr/man".
      **  Put a \ in front of each '.' and '+'.
      **  (this is an intentional memory leak)
      **/
-    oldpath = (char *) Tcl_GetVar2( interp, "env", argv[1], TCL_GLOBAL_ONLY);
+    oldpath = (char *) Tcl_GetVar2( interp, "env", argv[arg1], TCL_GLOBAL_ONLY);
     _TCLCHK(interp)
 
     if( oldpath == NULL)
-	oldpath = !strcmp( argv[1], "MANPATH") ? "/usr/man" : "";
+	oldpath = !strcmp( argv[arg1], "MANPATH") ? "/usr/man" : "";
 
     /**
      **  Split the new path into its components directories so each
      **  directory can be checked to see whether it is already in the 
      **  existing path.
      **/
-    if( !( pathlist = SplitIntoList( interp, (char *) argv[2], &numpaths)))
+    if( !( pathlist = SplitIntoList( interp, (char *) argv[arg1+1], &numpaths,
+	delim)))
 	goto unwind0;
 
     /**
      **  Some space for the list of paths which
      **  are not already in the existing path.
      **/
-    if((char *) NULL == (qualifiedpath = stringer(NULL,0, argv[2], ":", NULL)))
+    if((char *) NULL == (qualifiedpath = stringer(NULL,0, argv[arg1+1],
+	delim, NULL)))
 	if( OK != ErrorLogger( ERR_STRING, LOC, NULL))
 	    goto unwind1;
 
@@ -229,7 +251,7 @@ int	cmdSetPath(	ClientData	 client_data,
 	 **     only one  ... ^path$
 	 **/
 	if((char *) NULL == (newpath = stringer(NULL,0,
-		"(^", buffer, ":)|(:", buffer, ":)|(:",
+		"(^", buffer, delim, ")|(",delim, buffer, delim,")|(",delim,
 		buffer, "$)|(^", buffer, "$)",NULL)))
 	    if( OK != ErrorLogger( ERR_STRING, LOC, NULL))
 		goto unwind2;
@@ -246,7 +268,7 @@ int	cmdSetPath(	ClientData	 client_data,
 	    if ((char *) NULL ==
 		    stringer(qualifiedpath + strlen(qualifiedpath),
 		    qpathlen - strlen(qualifiedpath),
-		    pathlist[x], ":", NULL))
+		    pathlist[x], delim, NULL))
 		if( OK != ErrorLogger( ERR_STRING, LOC, NULL))
 		    goto unwind2;
 
@@ -260,7 +282,7 @@ int	cmdSetPath(	ClientData	 client_data,
     if( ! *qualifiedpath)
 	goto success1;
 
-    /* remove trailing ':' */
+    /* remove trailing delimiter */
     qualifiedpath[strlen(qualifiedpath) - 1] = '\0';
 
     /**
@@ -305,7 +327,8 @@ int	cmdSetPath(	ClientData	 client_data,
 		char ch = *endp;
 		*endp = '\0';
 		strcpy(newpath, oldpath);
-		if (newpath[strlen(newpath)-1] != ':')	strcat(newpath, ":");
+		if (newpath[strlen(newpath)-1] != *delim)
+			strcat(newpath, delim);
 		strcat(newpath, qualifiedpath);
 		*endp = ch;
 		strcat(newpath, endp);
@@ -313,9 +336,10 @@ int	cmdSetPath(	ClientData	 client_data,
 		char ch = *startp;
 		*startp = '\0';
 		strcpy(newpath, oldpath);
-		if (newpath[strlen(newpath)-1] != ':')	strcat(newpath, ":");
+		if (newpath[strlen(newpath)-1] != *delim)
+			strcat(newpath, delim);
 		strcpy(newpath, qualifiedpath);
-		if (*oldpath != ':')	strcat(newpath, ":");
+		if (*oldpath != *delim)	strcat(newpath, delim);
 		strcat(newpath, oldpath);
 		*startp = ch;
 		strcat(newpath, startp);
@@ -328,11 +352,12 @@ int	cmdSetPath(	ClientData	 client_data,
 	     **/
 	    if( !append) {
 		strcpy(newpath, qualifiedpath);
-		if (*oldpath != ':')	strcat(newpath, ":");
+		if (*oldpath != *delim)	strcat(newpath, delim);
 		strcat(newpath, oldpath);
 	    } else {
 		strcpy(newpath, oldpath);
-		if (newpath[strlen(newpath)-1] != ':')	strcat(newpath, ":");
+		if (newpath[strlen(newpath)-1] != *delim)
+			strcat(newpath, delim);
 		strcat(newpath, qualifiedpath);
 	    }
 
@@ -343,7 +368,7 @@ int	cmdSetPath(	ClientData	 client_data,
     /**
      **  Now the new value to be set resides in 'newpath'. Set it up.
      **/
-    moduleSetenv( interp, (char *) argv[1], newpath, 1);
+    moduleSetenv( interp, (char *) argv[arg1], newpath, 1);
     _TCLCHK(interp)
 
 #if WITH_DEBUGGING_CALLBACK
@@ -402,10 +427,12 @@ int	cmdRemovePath(	ClientData	 client_data,
 	       		int		 argc,
 	       		CONST84 char	*argv[])
 {
-    char	*sw_marker = APP_SW_MARKER;	/** arbitrary default	     **/
-    char	**pathlist;			/** List of dirs	     **/
-    int		 numpaths;			/** number of dirs in path   **/
-    int		 x;				/** loop index		     **/
+    char	 *sw_marker = APP_SW_MARKER,	/** arbitrary default	     **/
+		**pathlist;			/** List of dirs	     **/
+    const char	 *delim = _colon;		/** path delimiter	     **/
+    int		  numpaths,			/** number of dirs in path   **/
+		  arg1 = 1,			/** arg start		     **/
+		  x;				/** loop index		     **/
 
 
 #if WITH_DEBUGGING_CALLBACK
@@ -415,10 +442,11 @@ int	cmdRemovePath(	ClientData	 client_data,
     /**
      **   Check arguments. There should be give 3 args:
      **     argv[0]  -  prepend/append/remove-path
-     **     argv[1]  -  varname
-     **     argv[2]  -  value
+     **     ...
+     **     argv[n-1]-  varname
+     **     argv[n]  -  value
      **/
-    if(argc != 3)
+    if(argc < 3)
 	if( OK != ErrorLogger(ERR_USAGE,LOC,argv[0],"path-variable directory",
 	    NULL))
 	    goto unwind0;
@@ -453,20 +481,38 @@ int	cmdRemovePath(	ClientData	 client_data,
      ** For switch state3, we're looking to remove the markers.
      **/
     if( g_flags & M_SWSTATE3) 
-	argv[2] = sw_marker;
+	argv[arg1+1] = sw_marker;
+
+    /**
+     **  Check for the delimiter option
+     **/
+    if(*(argv[arg1]) == '-') {
+	if (!strcmp(argv[arg1], "-d")) {
+		delim = argv[arg1+1];
+		arg1 += 2;
+	} else if (!strcmp(argv[arg1], "--delim")) {
+		delim = argv[arg1+1];
+		arg1 += 2;
+	} else if (!strncmp(argv[arg1], "--delim=", 8)) {
+		delim = argv[arg1]+8;
+		arg1++;
+	}
+    }
 
     /**
      **  Split the path into its components so each item can be removed
      **  individually from the variable.
      **/
-    if( !( pathlist = SplitIntoList( interp, (char *) argv[2], &numpaths)))
+    if( !( pathlist = SplitIntoList( interp, (char *) argv[arg1+1], &numpaths,
+	delim)))
 	goto unwind0;
 
     /**
      ** Remove each item individually
      **/
     for( x = 0; x < numpaths; x++)
-	if(TCL_OK != Remove_Path(interp,(char *) argv[1],pathlist[x],sw_marker))
+	if(TCL_OK != Remove_Path(interp,(char *) argv[arg1],pathlist[x],
+	sw_marker, delim))
 	    goto unwind1;
 
 #if WITH_DEBUGGING_CALLBACK
@@ -505,6 +551,7 @@ unwind0:
  **							to remove item	     **
  **			char		*item		Item to remove	     **
  **			char		*sw_marker	Switch marker	     **
+ **			const char	*delim		path delimiter	     **
  ** 									     **
  **   Result:		int	TCL_OK		Successfull completion	     **
  **				TCL_ERROR	Any error		     **
@@ -519,7 +566,8 @@ unwind0:
 static int	Remove_Path(	Tcl_Interp	*interp,
 	       			char		*variable,
 	       			char		*item,
-				char		*sw_marker)
+				char		*sw_marker,
+				const char	*delim)
 {
     char	*oldpath,			/** Old value of 'var'	     **/
     		*tmppath,			/** Temp. buffer for 'var'   **/
@@ -564,7 +612,8 @@ static int	Remove_Path(	Tcl_Interp	*interp,
      **  Now we need to find it in the path variable.  So, we create
      **  space enough to build search expressions.
      **/
-    if((char *) NULL == (searchpath = stringer(NULL,0,"^", buffer, ":", NULL)))
+    if((char *) NULL == (searchpath = stringer(NULL,0,"^", buffer,
+	delim, NULL)))
 	if( OK != ErrorLogger( ERR_STRING, LOC, NULL))
 	    goto unwind1;
 
@@ -601,7 +650,7 @@ static int	Remove_Path(	Tcl_Interp	*interp,
 
     } else {
 
-	*searchpath = ':';	/* :buffer: */
+	*searchpath = *delim;	/* :buffer: */
 	midexpPtr = Tcl_RegExpCompile(interp, searchpath);
 	_TCLCHK(interp)
 
@@ -721,7 +770,7 @@ static int	Remove_Path(	Tcl_Interp	*interp,
 	*(startp + start_offset) = '\0';
 
 	if(*(endp + end_offset) == '\0') {
-	    (void) stringer(newenv, newlen, oldpath,":",sw_marker,NULL);
+	    (void) stringer(newenv, newlen, oldpath,delim,sw_marker,NULL);
 	} else {
 	    (void) stringer(newenv, newlen, oldpath,sw_marker,
 		endp + end_offset, NULL);
