@@ -40,7 +40,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdXResource.c,v 1.7 2006/01/17 22:51:34 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdXResource.c,v 1.7.12.1 2007/02/14 06:09:03 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -652,7 +652,7 @@ static	ErrType getOld( register char **buf)
 	if( OK != ErrorLogger( ERR_PARAM, LOC, "Resource database", NULL))
 	    return( ERR_PARAM);		/** ------- EXIT (PARAMETER) -----> **/
 
-    if( !(resDB.data = (Tcl_HashTable *) malloc( sizeof( Tcl_HashTable))))
+    if( !(resDB.data = (Tcl_HashTable *) module_malloc(sizeof(Tcl_HashTable))))
 	if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 	    return( ERR_ALLOC);		/** ----- EXIT (OUT OF MEMORY) ----> **/
 
@@ -738,7 +738,7 @@ static	ErrType	initBuffers(	Tcl_Interp *interp,
      **/
 
     if( !buffer) {
-	if( !(buffer = (Tcl_DString *) malloc( sizeof( Tcl_DString)))) {
+	if( !(buffer = (Tcl_DString *) module_malloc(sizeof(Tcl_DString)))) {
 	    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 		return( ERR_ALLOC);	/** ----- EXIT (OUT OF MEMORY) ----> **/
 	} else 
@@ -754,7 +754,7 @@ static	ErrType	initBuffers(	Tcl_Interp *interp,
 	defines[ def_base] = '\0';
     else if( is_file) {
 
-	if( !(defines = (char *) malloc( BUFSIZ * sizeof( char))))
+	if( !(defines = (char *) module_malloc(BUFSIZ * sizeof( char))))
 	    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 		return( ERR_ALLOC);	/** ----- EXIT (OUT OF MEMORY) ----> **/
 
