@@ -30,7 +30,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: error.c,v 1.8.6.1.4.1 2006/04/20 22:35:33 rkowen Exp $";
+static char Id[] = "@(#)$Id: error.c,v 1.8.6.1.8.2 2007/02/14 06:09:04 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -609,7 +609,7 @@ int Module_Error(	ErrType		  error_type,
      **  Build the argument array at first
      **/
 
-    if( NULL == (argv = (char **) malloc( listsize * sizeof( char *)))) {
+    if( NULL == (argv = (char **) module_malloc(listsize * sizeof( char *)))) {
 	module = module_name;
 	error_type = ERR_ALLOC;
 	NoArgs = 1;
@@ -957,6 +957,11 @@ static	int	FlushError(	ErrType		  Type,
 #if defined(HAVE_SYSLOG) && defined(WITH_LOGGING)
 	    int syslog_fac, syslog_lvl;
 
+	/* error output to stderr too if an error or verbose */
+	    if (Type >= NO_ERR_VERBOSE)
+		fprintf( stderr, "%s", errmsg_buffer);
+
+	/* now send to syslog */
 	    if( CheckFacility( fac, &syslog_fac, &syslog_lvl)) {
 		openlog( "modulecmd", LOG_PID, syslog_fac);
 		setlogmask( LOG_UPTO( syslog_lvl));
@@ -973,7 +978,7 @@ static	int	FlushError(	ErrType		  Type,
 
 #else
 #  ifdef	SYSLOG_DIR
-	    /* this is an intential memory leak */
+	    /* this is an intentional memory leak */
 	    buffer = stringer(NULL,0, SYSLOG_DIR, "/", fac);
 	    fac = buffer;
 #  endif
